@@ -17,7 +17,7 @@
  *                         and Technology (RIST). All rights reserved.
  * Copyright (c) 2016-2020 Intel, Inc.  All rights reserved.
  * Copyright (c) 2017      IBM Corporation. All rights reserved.
- * Copyright (c) 2021-2022 Nanook Consulting.  All rights reserved.
+ * Copyright (c) 2021-2023 Nanook Consulting.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -67,7 +67,7 @@ static void check_store(const char *name, const char *option,
              * a boolean value - the presence of the option in
              * the results is considered "true" */
             if (NULL != option) {
-                pmix_argv_append_nosize(&opt->values, option);
+                PMIx_Argv_append_nosize(&opt->values, option);
             }
             return;
         }
@@ -81,7 +81,7 @@ static void check_store(const char *name, const char *option,
      * a boolean value - the presence of the option in
      * the results is considered "true" */
     if (NULL != option) {
-        pmix_argv_append_nosize(&opt->values, option);
+        PMIx_Argv_append_nosize(&opt->values, option);
     }
     return;
 }
@@ -93,7 +93,7 @@ int pmix_cmd_line_parse(char **pargv, char *shorts,
                         char *helpfile)
 {
     int option_index = 0;   /* getopt_long stores the option index here. */
-    int n, opt, argc, argind;
+    int n, m, opt, argc, argind;
     bool found;
     char *ptr, *str, **argv;
     pmix_cmd_line_store_fn_t mystore;
@@ -102,7 +102,7 @@ int pmix_cmd_line_parse(char **pargv, char *shorts,
      * we have to protect it here - remove all leading/trailing
      * quotes to ensure we are looking at simple options/values */
     argv = pmix_argv_copy_strip(pargv);
-    argc = pmix_argv_count(argv);
+    argc = PMIx_Argv_count(argv);
     // assign a default store_fn if one isn't provided
     if (NULL == storefn) {
         mystore = check_store;
@@ -117,18 +117,21 @@ int pmix_cmd_line_parse(char **pargv, char *shorts,
     optopt = 0;
     optarg = NULL;
 
+    if (1 == argc) {
+        // nothing to parse
+        goto done;
+    }
+
     // run the parser
     while (1) {
         argind = optind;
-        // This is the executable, or we are at the last argument.
-        // Don't process any further.
         if (optind == argc || (optind > 0 && '-' != argv[optind][0])) {
+            // This is the executable, or we are at the last argument.
+            // Don't process any further.
             break;
         }
         opt = getopt_long(argc, argv, shorts, myoptions, &option_index);
-        if (-1 == opt) {
-            break;
-        }
+
         switch (opt) {
             case 0:
                 /* if this is an MCA param of some type, store it */
@@ -163,7 +166,7 @@ int pmix_cmd_line_parse(char **pargv, char *shorts,
                             printf("%s", str);
                             free(str);
                         }
-                        pmix_argv_free(argv);
+                        PMIx_Argv_free(argv);
                         return PMIX_OPERATION_SUCCEEDED;
                     }
                     if (0 == strcmp(ptr, "verbose") || 0 == strcmp(ptr, "v")) {
@@ -172,7 +175,7 @@ int pmix_cmd_line_parse(char **pargv, char *shorts,
                             printf("%s", str);
                             free(str);
                         }
-                        pmix_argv_free(argv);
+                        PMIx_Argv_free(argv);
                         return PMIX_OPERATION_SUCCEEDED;
                     }
                     if (0 == strcmp(ptr, "help") || 0 == strcmp(ptr, "h")) {
@@ -186,7 +189,7 @@ int pmix_cmd_line_parse(char **pargv, char *shorts,
                             printf("%s", str);
                             free(str);
                         }
-                        pmix_argv_free(argv);
+                        PMIx_Argv_free(argv);
                         return PMIX_OPERATION_SUCCEEDED;
                     }
                     /* see if we have help on that subject */
@@ -203,7 +206,7 @@ int pmix_cmd_line_parse(char **pargv, char *shorts,
                         printf("%s", str);
                         free(str);
                     }
-                    pmix_argv_free(argv);
+                    PMIx_Argv_free(argv);
                     return PMIX_OPERATION_SUCCEEDED;
                 } else if (NULL == optarg) {
                     // high-level help request
@@ -216,7 +219,7 @@ int pmix_cmd_line_parse(char **pargv, char *shorts,
                         printf("%s", str);
                         free(str);
                     }
-                    pmix_argv_free(argv);
+                    PMIx_Argv_free(argv);
                     return PMIX_OPERATION_SUCCEEDED;
                 } else {  // unrecognized option
                     str = pmix_show_help_string("help-cli.txt", "unrecognized-option", true,
@@ -226,7 +229,7 @@ int pmix_cmd_line_parse(char **pargv, char *shorts,
                         free(str);
                     }
                 }
-                pmix_argv_free(argv);
+                PMIx_Argv_free(argv);
                 return PMIX_ERR_SILENT;
             case 'V':
                 str = pmix_show_help_string(helpfile, "version", false,
@@ -238,15 +241,24 @@ int pmix_cmd_line_parse(char **pargv, char *shorts,
                     free(str);
                 }
                 // if they ask for the version, that is all we do
-                pmix_argv_free(argv);
+                PMIx_Argv_free(argv);
                 return PMIX_OPERATION_SUCCEEDED;
-            default:
-                /* this could be one of the short options other than 'h' or 'V', so
-                 * we have to check */
-                if (0 != argind && '-' != argv[argind][0]) {
-                    // this was not an option
+            case 'v':
+                /* if the argv at this point is not pointing at a string
+                 * starting with "-v", then we just ignore it - the user
+                 * has passed a string with multiple 'v's in it and we
+                 * need to wait until the end */
+                if (0 != strncmp(argv[optind-1], "-v", 2)) {
                     break;
                 }
+                /* we store the 'v' option with a value equal to the
+                 * number of 'v's the user provided */
+                n = strlen(&argv[optind-1][1]);
+                pmix_asprintf(&str, "%d", n);
+                mystore(myoptions[option_index].name, str, results);
+                free(str);
+                break;
+            default:
                 found = false;
                 for (n=0; '\0' != shorts[n]; n++) {
                     int ascii = shorts[n];
@@ -281,9 +293,9 @@ int pmix_cmd_line_parse(char **pargv, char *shorts,
                         } else {
                             ptr = NULL;
                         }
-                        for (n=0; NULL != myoptions[n].name; n++) {
-                            if (ascii == myoptions[n].val) {
-                                if (PMIX_ARG_NONE == myoptions[n].has_arg) {
+                        for (m=0; NULL != myoptions[m].name; m++) {
+                            if (ascii == myoptions[m].val) {
+                                if (PMIX_ARG_NONE == myoptions[m].has_arg) {
                                     /* if ptr isn't NULL, then that means we were given
                                      * an argument to an option that doesn't take one.
                                      * Report the error */
@@ -294,17 +306,17 @@ int pmix_cmd_line_parse(char **pargv, char *shorts,
                                             printf("%s", str);
                                             free(str);
                                         }
-                                        pmix_argv_free(argv);
+                                        PMIx_Argv_free(argv);
                                         return PMIX_ERR_SILENT;
                                     }
                                     ptr = NULL;
-                                } else if (0 == strcmp(myoptions[n].name, "np") &&
+                                } else if (0 == strcmp(myoptions[m].name, "np") &&
                                            0 == strcmp(optarg, "p")) {
                                     /* we special-case the very common "-np" option */
                                     ptr = argv[optind];
                                     ++optind;
                                 }
-                                mystore(myoptions[n].name, ptr, results);
+                                mystore(myoptions[m].name, ptr, results);
                                 found = true;
                                 break;
                             }
@@ -312,13 +324,26 @@ int pmix_cmd_line_parse(char **pargv, char *shorts,
                         if (found) {
                             break;
                         }
+                        /* this could be one of the short options other than 'h' or 'V', so
+                         * we have to check */
+                        if (0 != argind && '-' != argv[argind][0]) {
+                            // this was not an option
+                            goto done;
+                        }
+                        if (0 == strcmp(argv[optind-1], "--")) {
+                            // double-dash indicates separator between launcher
+                            // directives and the application
+                            results->tail = PMIx_Argv_copy(&argv[optind]);
+                            PMIx_Argv_free(argv);
+                            return PMIX_SUCCESS;
+                        }
                         str = pmix_show_help_string("help-cli.txt", "short-no-long", true,
-                                                    pmix_tool_basename, argv[optind-1]);
+                                                    pmix_tool_basename, shorts[n]);
                         if (NULL != str) {
                             printf("%s", str);
                             free(str);
                         }
-                        pmix_argv_free(argv);
+                        PMIx_Argv_free(argv);
                         return PMIX_ERR_SILENT;
                     }
                 }
@@ -341,28 +366,39 @@ int pmix_cmd_line_parse(char **pargv, char *shorts,
                             printf("%s", str);
                             free(str);
                         }
-                        pmix_argv_free(argv);
+                        PMIx_Argv_free(argv);
                         return PMIX_ERR_SILENT;
                     }
                 }
+                if (0 == strcmp(argv[optind-1], "--")) {
+                    // double-dash indicates separator between launcher
+                    // directives and the application
+                    goto done;
+                }
+                if (1 == optind) {
+                    // command without any options
+                    goto done;
+                }
                 str = pmix_show_help_string("help-cli.txt", "unregistered-option", true,
                                             pmix_tool_basename, argv[optind-1], pmix_tool_basename);
                 if (NULL != str) {
                     printf("%s", str);
                     free(str);
                 }
-                pmix_argv_free(argv);
+                PMIx_Argv_free(argv);
                 return PMIX_ERR_SILENT;
         }
     }
+
+done:
     if (optind < argc) {
         /* if this is an '&', it simply indicates that the executable
          * was being pushed into the background - ignore it */
         if (0 != strcmp(argv[optind], "&")) {
-            results->tail = pmix_argv_copy(&argv[optind]);
+            results->tail = PMIx_Argv_copy(&argv[optind]);
         }
     }
-    pmix_argv_free(argv);
+    PMIx_Argv_free(argv);
     return PMIX_SUCCESS;
 }
 
@@ -377,7 +413,7 @@ static void ides(pmix_cli_item_t *p)
         free(p->key);
     }
     if (NULL != p->values) {
-        pmix_argv_free(p->values);
+        PMIx_Argv_free(p->values);
     }
 }
 PMIX_EXPORT PMIX_CLASS_INSTANCE(pmix_cli_item_t,
@@ -393,7 +429,7 @@ static void odes(pmix_cli_result_t *p)
 {
     PMIX_LIST_DESTRUCT(&p->instances);
     if (NULL != p->tail) {
-        pmix_argv_free(p->tail);
+        PMIx_Argv_free(p->tail);
     }
 }
 PMIX_EXPORT PMIX_CLASS_INSTANCE(pmix_cli_result_t,
